==> brmo-stufbg204-1.6.2-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDPRSRel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.TijdvakGeldigheid;
import nl.egem.stuf.stuf0204.TijdvakRelatie;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * relatie entiteit huishouden prs
 * 
 * <p>Java class for HHDPRS-rel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHDPRS-rel">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="huishoudenRelatieCode" minOccurs="0">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>HuishoudenRelatieCode">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="tijdvakRelatie" type="{http://www.egem.nl/StUF/StUF0204}TijdvakRelatie" minOccurs="0"/>
 *         &lt;element name="tijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}TijdvakGeldigheid" minOccurs="0"/>
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}relatie"/>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHDPRS-rel", propOrder = {
    "huishoudenRelatieCode",
    "tijdvakRelatie",
    "tijdvakGeldigheid",
    "extraElementen"
})
@XmlSeeAlso({
    nl.egem.stuf.sector.bg._0204.HHDAntwoord.HHDPRS.class,
    nl.egem.stuf.sector.bg._0204.HHDKennisgeving.HHDPRS.class,
    nl.egem.stuf.sector.bg._0204.HHDVraag.HHDPRS.class
})
public class HHDPRSRel {

    @XmlElementRef(name = "huishoudenRelatieCode", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDPRSRel.HuishoudenRelatieCode> huishoudenRelatieCode;
    protected TijdvakRelatie tijdvakRelatie;
    protected TijdvakGeldigheid tijdvakGeldigheid;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the huishoudenRelatieCode property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDPRSRel.HuishoudenRelatieCode }{@code >}
     *     
     */
    public JAXBElement<HHDPRSRel.HuishoudenRelatieCode> getHuishoudenRelatieCode() {
        return huishoudenRelatieCode;
    }

    /**
     * Sets the value of the huishoudenRelatieCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDPRSRel.HuishoudenRelatieCode }{@code >}
     *     
     */
    public void setHuishoudenRelatieCode(JAXBElement<HHDPRSRel.HuishoudenRelatieCode> value) {
        this.huishoudenRelatieCode = value;
    }

    /**
     * Gets the value of the tijdvakRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakRelatie }
     *     
     */
    public TijdvakRelatie getTijdvakRelatie() {
        return tijdvakRelatie;
    }

    /**
     * Sets the value of the tijdvakRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakRelatie }
     *     
     */
    public void setTijdvakRelatie(TijdvakRelatie value) {
        this.tijdvakRelatie = value;
    }

    /**
     * Gets the value of the tijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public TijdvakGeldigheid getTijdvakGeldigheid() {
        return tijdvakGeldigheid;
    }

    /**
     * Sets the value of the tijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public void setTijdvakGeldigheid(TijdvakGeldigheid value) {
        this.tijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "R";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>HuishoudenRelatieCode">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class HuishoudenRelatieCode {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/HHDPRSRel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.TijdvakGeldigheid;
import nl.egem.stuf.stuf0204.TijdvakRelatie;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * relatie entiteit huishouden prs
 * 
 * <p>Java class for HHDPRS-rel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HHDPRS-rel"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="huishoudenRelatieCode" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;HuishoudenRelatieCode"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="tijdvakRelatie" type="{http://www.egem.nl/StUF/StUF0204}TijdvakRelatie" minOccurs="0"/&gt;
 *         &lt;element name="tijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}TijdvakGeldigheid" minOccurs="0"/&gt;
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}relatie"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HHDPRS-rel", propOrder = {
    "huishoudenRelatieCode",
    "tijdvakRelatie",
    "tijdvakGeldigheid",
    "extraElementen"
})
@XmlSeeAlso({
    nl.egem.stuf.sector.bg._0204.HHDKennisgeving.HHDPRS.class,
    nl.egem.stuf.sector.bg._0204.HHDVraag.HHDPRS.class,
    nl.egem.stuf.sector.bg._0204.HHDAntwoord.HHDPRS.class
})
public class HHDPRSRel {

    @XmlElementRef(name = "huishoudenRelatieCode", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<HHDPRSRel.HuishoudenRelatieCode> huishoudenRelatieCode;
    protected TijdvakRelatie tijdvakRelatie;
    protected TijdvakGeldigheid tijdvakGeldigheid;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the huishoudenRelatieCode property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link HHDPRSRel.HuishoudenRelatieCode }{@code >}
     *     
     */
    public JAXBElement<HHDPRSRel.HuishoudenRelatieCode> getHuishoudenRelatieCode() {
        return huishoudenRelatieCode;
    }

    /**
     * Sets the value of the huishoudenRelatieCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link HHDPRSRel.HuishoudenRelatieCode }{@code >}
     *     
     */
    public void setHuishoudenRelatieCode(JAXBElement<HHDPRSRel.HuishoudenRelatieCode> value) {
        this.huishoudenRelatieCode = value;
    }

    /**
     * Gets the value of the tijdvakRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakRelatie }
     *     
     */
    public TijdvakRelatie getTijdvakRelatie() {
        return tijdvakRelatie;
    }

    /**
     * Sets the value of the tijdvakRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakRelatie }
     *     
     */
    public void setTijdvakRelatie(TijdvakRelatie value) {
        this.tijdvakRelatie = value;
    }

    /**
     * Gets the value of the tijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public TijdvakGeldigheid getTijdvakGeldigheid() {
        return tijdvakGeldigheid;
    }

    /**
     * Sets the value of the tijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public void setTijdvakGeldigheid(TijdvakGeldigheid value) {
        this.tijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "R";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;HuishoudenRelatieCode"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class HuishoudenRelatieCode {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}
